summaryrefslogtreecommitdiffstats
path: root/filesharing/advanced/kcm_sambaconf/sambafile.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'filesharing/advanced/kcm_sambaconf/sambafile.cpp')
-rw-r--r--filesharing/advanced/kcm_sambaconf/sambafile.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/filesharing/advanced/kcm_sambaconf/sambafile.cpp b/filesharing/advanced/kcm_sambaconf/sambafile.cpp
index 2ba52a57..50df27c0 100644
--- a/filesharing/advanced/kcm_sambaconf/sambafile.cpp
+++ b/filesharing/advanced/kcm_sambaconf/sambafile.cpp
@@ -146,7 +146,7 @@ bool SambaFile::slotApply()
// we simply save the values to it
// if not we have to save the results in
// a temporary file and copy it afterwards
// over the smb.conf file with kdesu.
if (TQFileInfo(path).isWritable())
{
saveTo(path);
@@ -177,7 +177,7 @@ bool SambaFile::slotApply()
.tqarg(_tempFile->name())
.tqarg(path)
.tqarg(_tempFile->name());
- proc << "kdesu" << "-d" << suCommand;
+ proc << "tdesu" << "-d" << suCommand;
if (! proc.start(KProcess::Block)) {
kdDebug(5009) << "SambaFile::slotApply: saving to " << path << " failed!" << endl;
@@ -146,7 +146,7 @@ bool SambaFile::slotApply()
// if not we have to save the results in
// a temporary file and copy it afterwards
- // over the smb.conf file with kdesu.
+ // over the smb.conf file with tdesu.
if (TQFileInfo(path).isWritable())
{